@@ -5,9 +5,10 @@ from django.conf.urls import url, include
 from django.template.defaultfilters import lower
 from django.core.exceptions import ImproperlyConfigured
 
+import import_string
+
 from is_core.config import settings
 
-from .utils import str_to_class
 from .loading import get_cores
 from .patterns import RESTPattern
 from .rest.resource import EntryPointResource
@@ -69,19 +70,19 @@ class ISSite:
         urlpatterns = []
         if settings.AUTH_LOGIN_VIEW:
             urlpatterns.append(
-                url(r'^{}$'.format(settings.LOGIN_URL[1:]), str_to_class(settings.AUTH_LOGIN_VIEW).as_view(
-                    form_class=str_to_class(settings.AUTH_FORM_CLASS)), name='login')
+                url(r'^{}$'.format(settings.LOGIN_URL[1:]), import_string(settings.AUTH_LOGIN_VIEW).as_view(
+                    form_class=import_string(settings.AUTH_FORM_CLASS)), name='login')
             )
 
         if settings.AUTH_LOGOUT_VIEW:
             urlpatterns.append(
                 url(r'^{}$'.format(settings.LOGOUT_URL[1:]),
-                    str_to_class(settings.AUTH_LOGOUT_VIEW).as_view(), name='logout')
+                    import_string(settings.AUTH_LOGOUT_VIEW).as_view(), name='logout')
             )
 
         if settings.AUTH_RESOURCE_CLASS:
-            auth_resource_class = str_to_class(settings.AUTH_RESOURCE_CLASS)
-            auth_resource_class.form_class = str_to_class(settings.AUTH_FORM_CLASS)
+            auth_resource_class = import_string(settings.AUTH_RESOURCE_CLASS)
+            auth_resource_class.form_class = import_string(settings.AUTH_FORM_CLASS)
             pattern = RESTPattern('api-login', self.name, settings.LOGIN_API_URL[1:],
                                   auth_resource_class)
             urlpatterns.append(pattern.get_url())
@@ -89,7 +90,7 @@ class ISSite:
         if settings.AUTH_LOGIN_CODE_VERIFICATION_VIEW:
             urlpatterns.append(
                 url(r'^{}$'.format(settings.CODE_VERIFICATION_URL[1:]),
-                    str_to_class(settings.AUTH_LOGIN_CODE_VERIFICATION_VIEW).as_view(), name='code-verification-login')
+                    import_string(settings.AUTH_LOGIN_CODE_VERIFICATION_VIEW).as_view(), name='code-verification-login')
             )
 
         pattern = RESTPattern('api', self.name, r'api/', EntryPointResource)
